Getting started — stanpy 0.2.6 documentation

# Getting started

## Stable release

To install stanpy, run this command in your terminal:

    $ pip install stanpy

This is the preferred method to install stanpy, as it will always install the most recent stable release.

If you don't have pip installed, this Python installation guide can guide you through the process.

## From sources

The sources for stanpy can be downloaded from the Github repo.

You can either clone the public repository:

    $ git clone git://github.com/david/stanpy

Or download the tarball:

    $ curl -OJL https://github.com/david/stanpy/tarball/master

Once you have a copy of the source, you can install it with:

    $ python setup.py install

previous

Overview

next

User Guide